@@ -27,6 +27,7 @@ import time
 import sys
 import logging
 
+import numpy
 import tables
 
 from qtpy import QtCore
@@ -549,12 +550,12 @@ class VTApp(QtCore.QObject):
 
         # Make a copy of the selected file
         try:
-            QtWidgets.qApp.setOverrideCursor(
+            QtWidgets.QApplication.setOverrideCursor(
                 QtGui.QCursor(QtCore.Qt.WaitCursor))
             dbdoc = self.gui.dbs_tree_model.getDBDoc(initial_filepath)
             dbdoc.copy_file(filepath)
         finally:
-            QtWidgets.qApp.restoreOverrideCursor()
+            QtWidgets.QApplication.restoreOverrideCursor()
 
         # Close the copied file (which is not necessarely selected in
         # the tree view because closing an overwritten file can change
@@ -1246,7 +1247,7 @@ class VTApp(QtCore.QObject):
                                'Caption of the Versions dialog'),
             'Python': pyversion,
             'PyTables': tables.__version__,
-            'NumPy': tables.numpy.__version__,
+            'NumPy': numpy.__version__,
             'Qt': QtCore.qVersion(),
             'PyQt': QtCore.PYQT_VERSION_STR,
             'ViTables': vtconfig.getVersion()
