@@ -74,7 +74,7 @@ class VTSplash(QtWidgets.QSplashScreen):
         :Parameter msg: the message to be displayed
         """
 
-        QtWidgets.qApp.processEvents()
+        QtWidgets.QApplication.processEvents()
         self.msg = msg
         self.showMessage(self.msg)
         time.sleep(0.500)
